@@ -19,7 +19,7 @@ class FieldDefinition(OrderedDict):
         return self
 
     def __eq__(self, other):
-        return str(self) == str(other)
+        return str(self).lower() == str(other).lower()
 
 class FieldList(list):
     def __init__(self,):
